import { defineStore } from 'pinia'
import type { Object, ZoneObject, Zone } from '@/types'

export const useZoneEditorStore = defineStore('zoneEditor', {
  state: () => ({
    active: true,
    zone: null as Zone | null,
    tool: 'move',
    drawMode: 'tile',
    tileList: [] as string[],
    objectList: [] as Object[],
    selectedTile: '',
    selectedObject: null as Object | null,
    isZoneListModalShown: false,
    isCreateZoneModalShown: false,
    isSettingsModalShown: false
  }),
  actions: {
    toggleActive() {
      this.active = !this.active
    },
    setZone(zone: Zone) {
      this.zone = zone
    },
    setTool(tool: string) {
      this.tool = tool
    },
    setDrawMode(mode: string) {
      this.drawMode = mode
    },
    setTileList(tiles: string[]) {
      this.tileList = tiles
    },
    setObjectList(objects: Object[]) {
      this.objectList = objects
    },
    setSelectedTile(tile: string) {
      this.selectedTile = tile
    },
    setSelectedObject(object: any) {
      this.selectedObject = object
    },
    toggleSettingsModal() {
      this.isSettingsModalShown = !this.isSettingsModalShown
    },
    toggleZoneListModal() {
      this.isZoneListModalShown = !this.isZoneListModalShown
      this.isCreateZoneModalShown = false
    },
    toggleCreateZoneModal() {
      this.isCreateZoneModalShown = !this.isCreateZoneModalShown
    },
    reset() {
      this.tileList = []
      this.objectList = []
      this.tool = 'move'
      this.drawMode = 'tile'
      this.selectedTile = ''
      this.selectedObject = null
      this.isSettingsModalShown = false
      this.isZoneListModalShown = false
      this.isCreateZoneModalShown = false
    }
  }
})